@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2021 PyTroll Community
+# Copyright (c) 2013 - 2021, 2024 PyTroll Community
 
 # Author(s):
 
@@ -41,7 +41,6 @@ import numpy as np
 
 from pyorbital.geoloc import ScanGeometry
 
-
 ################################################################
 #
 #   AVHRR
@@ -78,7 +77,7 @@ def avhrr(scans_nb, scan_points,
 
 def avhrr_gac(scan_times, scan_points,
               scan_angle=55.37, frequency=0.5):
-    """Definition of the avhrr instrument, gac version
+    """Definition of the avhrr instrument, gac version.
 
     Source: NOAA KLM User's Guide, Appendix J
     http://www.ncdc.noaa.gov/oa/pod-guide/ncdc/docs/klm/html/j/app-j.htm
@@ -108,6 +107,7 @@ def avhrr_gac(scan_times, scan_points,
 
 
 def avhrr_all_geom(scans_nb):
+    """Get all the AVHRR scan points."""
     # we take all pixels
     scan_points = np.arange(2048)
     return avhrr(scans_nb, scan_points)
@@ -119,7 +119,7 @@ def avhrr_all_geom(scans_nb):
 
 
 def avhrr_edge_geom(scans_nb):
-    # we take only edge pixels
+    """Getting the AVHRR scan edges only."""
     scan_points = np.array([0, 2047])
     return avhrr(scans_nb, scan_points)
 
@@ -130,7 +130,7 @@ def avhrr_edge_geom(scans_nb):
 
 
 def avhrr_40_geom(scans_nb):
-    # we take only every 40th pixel
+    """Description of the AVHRR scan in terms of every 40th pixel per line."""
     scan_points = np.arange(24, 2048, 40)
     return avhrr(scans_nb, scan_points)
 
@@ -144,6 +144,7 @@ def avhrr_40_geom(scans_nb):
 def viirs(scans_nb, scan_indices=slice(0, None),
           chn_pixels=6400, scan_lines=32, scan_step=1):
     """Describe VIIRS instrument geometry, I-band by default.
+
     VIIRS scans several lines simultaneously (there are 16 detectors for each
     M-band, 32 detectors for each I-band) so the scan angles (and times) are
     two-dimensional arrays, contrary to AVHRR for example.
@@ -154,9 +155,8 @@ def viirs(scans_nb, scan_indices=slice(0, None),
                99 emtpy (excluded) scans
 
     """
-
     entire_width = np.arange(chn_pixels)
-    scan_points = entire_width[scan_indices].astype('int')
+    scan_points = entire_width[scan_indices].astype("int")
     scan_pixels = len(scan_points)
 
     # Initial angle 55.84 deg replaced with 56.28 deg found in
@@ -198,7 +198,7 @@ def viirs(scans_nb, scan_indices=slice(0, None),
 
 
 def viirs_edge_geom(scans_nb):
-    # we take only edge pixels
+    """Definition of the VIIRS scane edges."""
     scan_indices = [0, -1]
     return viirs(scans_nb, scan_indices)
 
@@ -210,7 +210,7 @@ def viirs_edge_geom(scans_nb):
 ################################################################
 
 def amsua(scans_nb, scan_points=None):
-    """ Describe AMSU-A instrument geometry
+    """Describe AMSU-A instrument geometry.
 
     Parameters:
        scans_nb | int -  number of scan lines
@@ -222,7 +222,6 @@ def amsua(scans_nb, scan_points=None):
        pyorbital.geoloc.ScanGeometry object
 
     """
-
     scan_len = 30  # 30 samples per scan
     scan_rate = 8  # single scan, seconds
     scan_angle = -48.3  # swath, degrees
@@ -255,7 +254,7 @@ def amsua(scans_nb, scan_points=None):
 ################################################################
 
 def mhs(scans_nb, scan_points=None):
-    """ Describe MHS instrument geometry
+    """Describe MHS instrument geometry.
 
     See:
 
@@ -274,7 +273,6 @@ def mhs(scans_nb, scan_points=None):
        pyorbital.geoloc.ScanGeometry object
 
     """
-
     scan_len = 90  # 90 samples per scan
     scan_rate = 8 / 3.  # single scan, seconds
     scan_angle = -49.444  # swath, degrees
@@ -332,7 +330,6 @@ def hirs4(scans_nb, scan_points=None):
        pyorbital.geoloc.ScanGeometry object
 
     """
-
     scan_len = 56  # 56 samples per scan
     scan_rate = 6.4  # single scan, seconds
     scan_angle = -49.5  # swath, degrees
@@ -363,7 +360,8 @@ def hirs4(scans_nb, scan_points=None):
 ################################################################
 
 def atms(scans_nb, scan_points=None):
-    """ Describe ATMS instrument geometry
+    """Describe ATMS instrument geometry.
+
     See:
 
     - https://dtcenter.org/com-GSI/users/docs/presentations/2013_workshop/
@@ -382,7 +380,6 @@ def atms(scans_nb, scan_points=None):
        pyorbital.geoloc.ScanGeometry object
 
     """
-
     scan_len = 96  # 96 samples per scan
     scan_rate = 8 / 3.  # single scan, seconds
     scan_angle = -52.7  # swath, degrees
@@ -413,7 +410,7 @@ def atms(scans_nb, scan_points=None):
 ################################################################
 
 def mwhs2(scans_nb, scan_points=None):
-    """Describe MWHS-2 instrument geometry
+    """Describe MWHS-2 instrument geometry.
 
     The scanning period is 2.667 s. Main beams of the antenna scan over the ob-
     serving swath (±53.35◦ from nadir) in the cross-track direction at a
@@ -434,7 +431,6 @@ def mwhs2(scans_nb, scan_points=None):
        pyorbital.geoloc.ScanGeometry object
 
     """
-
     scan_len = 98  # 98 samples per scan
     scan_rate = 8 / 3.  # single scan, seconds
     scan_angle = -53.35  # swath, degrees
@@ -485,7 +481,6 @@ def olci(scans_nb, scan_points=None):
     Source: Sentinel-3 OLCI Coverage
     https://sentinel.esa.int/web/sentinel/user-guides/sentinel-3-olci/coverage
     """
-
     if scan_points is None:
         scan_len = 4000  # samples per scan
         scan_points = np.arange(4000)
@@ -515,11 +510,11 @@ def olci(scans_nb, scan_points=None):
 
 
 def ascat(scan_nb, scan_points=None):
-    """ASCAT make two scans one to the left and one to the right of the
-    sub-satellite track.
+    """Describing the ASCAT scanning geometry.
 
+    make two scans one to the left and one to the right of the sub-satellite
+    track.
     """
-
     if scan_points is None:
         scan_len = 42  # samples per scan
         scan_points = np.arange(42)
@@ -553,3 +548,29 @@ def ascat(scan_nb, scan_points=None):
                      [np.int32(scan_nb), 1]) + np.expand_dims(offset, 1))
 
     return ScanGeometry(inst, times)
+
+
+def slstr_nadir(scans_nb, scan_points=None):
+    """Definition of the SLSTR instrument nadir swath.
+
+    Source: Sentinel-3 SLSTR Coverage
+    https://sentinel.esa.int/web/sentinel/user-guides/Sentinel-3-slstr/coverage
+    """
+    if scan_points is None:
+        scan_len = 3000  # samples per scan
+        scan_points = np.arange(scan_len)
+    else:
+        scan_len = len(scan_points)
+    scan_angle_west = 46.5  # swath, degrees
+    scan_angle_east = -22.1  # swath, degrees
+
+    # build the slstr instrument scan line angles
+    scanline_angles = np.linspace(np.deg2rad(scan_angle_west),
+                                  np.deg2rad(scan_angle_east), scan_len)
+    inst = np.vstack((scanline_angles, np.zeros(scan_len,)))
+
+    inst = np.tile(inst[:, np.newaxis, :], [1, np.int32(scans_nb), 1])
+
+    times = np.tile(np.zeros_like(scanline_angles), [np.int32(scans_nb), 1])
+
+    return ScanGeometry(inst, times)
