@@ -22,11 +22,13 @@
 
 """Test the geoloc module."""
 
+
 from datetime import datetime
+
 import numpy as np
 
 from pyorbital.geoloc import ScanGeometry, geodetic_lat, qrotate, subpoint
-from pyorbital.geoloc_instrument_definitions import avhrr, viirs, amsua, mhs, hirs4, atms, ascat
+from pyorbital.geoloc_instrument_definitions import amsua, ascat, atms, avhrr, hirs4, mhs, slstr_nadir, viirs
 
 
 class TestQuaternion:
@@ -110,8 +112,8 @@ class TestGeoloc:
         times = instrument.times(start_of_scan)
 
         assert times[0, 1] == start_of_scan
-        assert times[0, 0] == start_of_scan - np.timedelta64(100, 'ms')
-        assert times[0, 2] == start_of_scan + np.timedelta64(100, 'ms')
+        assert times[0, 0] == start_of_scan - np.timedelta64(100, "ms")
+        assert times[0, 2] == start_of_scan + np.timedelta64(100, "ms")
 
     def test_geodetic_lat(self):
         """Test the determination of the geodetic latitude."""
@@ -290,3 +292,16 @@ class TestGeolocDefs:
         geom = ascat(1, np.array([0, -1]))
         np.testing.assert_allclose(
             geom.fovs, expected_fovs, rtol=1e-2, atol=1e-2)
+
+    def test_slstr_nadir(self):
+        """Test the definition of the slstr instrument nadir view flying on Sentinel-3."""
+        geom = slstr_nadir(1, [0, 1])
+
+        expected_fovs = np.array([
+            np.tile(np.array([[0.8115781, -0.38571776]]), [1, 1]),
+            np.tile(np.array([[0., 0.]]), [1, 1])], dtype=np.float64)
+        np.testing.assert_allclose(geom.fovs, expected_fovs, rtol=1e-2, atol=1e-2)
+
+        geom = slstr_nadir(1, None)
+
+        np.testing.assert_equal(geom.fovs.size, 6000)
